% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/cohens_d.R, R/print.effectsize_difference.R
\name{cohens_d}
\alias{cohens_d}
\alias{hedges_g}
\alias{glass_delta}
\alias{print.effectsize_difference}
\title{Effect size for differences}
\usage{
cohens_d(
  x,
  y = NULL,
  data = NULL,
  correction = FALSE,
  pooled_sd = TRUE,
  paired = FALSE,
  ci = 0.95
)

hedges_g(
  x,
  y = NULL,
  data = NULL,
  correction = FALSE,
  pooled_sd = TRUE,
  paired = FALSE,
  ci = 0.95
)

glass_delta(x, y = NULL, data = NULL, correction = FALSE, ci = 0.95)

\method{print}{effectsize_difference}(x, digits = 2, append_CL = FALSE, ...)
}
\arguments{
\item{x}{A formula, a numeric vector, or a character name of one in \code{data}.
(For \code{print()} the result of one of the standardized difference functions.)}

\item{y}{A numeric vector, a grouping (character / factor) vector, a or a
character  name of one in \code{data}. Ignored if \code{x} is a formula.}

\item{data}{An optional data frame containing the variables.}

\item{correction}{If \code{TRUE}, applies a correction to make it less biased for
small samples (McGrath & Meyer, 2006).}

\item{pooled_sd}{If \code{TRUE} (default), a \code{\link[=sd_pooled]{sd_pooled()}} is used (assuming equal
variance). Else the mean SD from both groups is used instead.}

\item{paired}{If \code{TRUE}, the values of \code{x} and \code{y} are considered as paired.}

\item{ci}{Confidence Interval (CI) level}

\item{digits}{Number of significant digits.}

\item{append_CL}{Should the Common Language Effect Sizes be printed as well?
Not applicable to Glass' Delta (See \code{\link[=d_to_common_language]{d_to_common_language()}})}

\item{...}{Not used.}
}
\value{
A data frame with the effect size(s) and confidence interval(s).
\subsection{Confidence Intervals}{

Confidence intervals are estimated using the Noncentrality parameter method;
These methods searches for a the best \code{ncp} (non-central parameters) for
of the noncentral t distribution for the desired tail-probabilities,
and then convert these \code{ncp}s to the corresponding effect sizes.
}
}
\description{
Compute different indices of effect size. For very small sample sizes (n <
20) Hedges' g is considered as less biased than Cohen's d. For sample sizes >
20, the results for both statistics are roughly equivalent.
\cr\cr
The Glass’s delta is appropriate if standard deviations are significantly
different between groups, as it uses only the \emph{second} group's standard
deviation.
}
\examples{
cohens_d(iris$Sepal.Length, iris$Sepal.Width)
hedges_g("Sepal.Length", "Sepal.Width", data = iris)

cohens_d(mpg ~ am, data = mtcars)
cohens_d(mpg ~ am, data = mtcars, pooled_sd = FALSE)
hedges_g(mpg ~ am, data = mtcars)
glass_delta(mpg ~ am, data = mtcars)

print(cohens_d(mpg ~ am, data = mtcars), append_CL = TRUE)

}
\references{
\itemize{
\item Cohen, J. (2013). Statistical power analysis for the behavioral sciences. Routledge.
\item McGrath, R. E., & Meyer, G. J. (2006). When effect sizes disagree: the case of r and d. Psychological methods, 11(4), 386.
\item Hedges, L. V. & Olkin, I. (1985). Statistical methods for meta-analysis. Orlando, FL: Academic Press.
}
}
\seealso{
\code{\link[=d_to_common_language]{d_to_common_language()}}
}
